# Changelog
All notable changes to charset-normalizer will be documented in this file. This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## 0.1.2 (2025-04-01)

### Fixed
- Missing `faker` dependency.

## 0.1.1 (2025-04-01)

### Added
- Database overview at end in addition to start (CLI).

### Fixed
- Target schema was not respected when setting focus in the `load` method.

### Changed
- Use `piou` https://github.com/Andarius/piou instead of the stdlib argparse library.

## 0.1.0 (2025-03-28)

### Added
- initial release
